@@ -74,7 +74,7 @@ def keeper(
     ),
     agent_ips: str = typer.Option(
         "",
-        envvar=f"{PREFIX}_AGENT_IP",
+        envvar=f"{PREFIX}_AGENT_IPS",
         show_envvar=False,
     ),
 ):
